@@ -9,9 +9,9 @@
 
 from mo_files import File
 from mo_future import get_function_name
+from mo_imports import export
 
-from mo_streams import ByteStream
-from mo_streams.utils import os_path
+from mo_streams._utils import ByteStream
 
 DECODERS = {
     "zst": ByteStream.from_zst,
@@ -50,7 +50,12 @@ def _extend(cls):
 
 @_extend(File)
 def content(self):
-    return _get_file_stream(self.abspath, ByteStream(open(os_path(self), "rb")))
+    return _get_file_stream(self.os_path, ByteStream(open(self.os_path, "rb")))
+
+
+@_extend(File)
+def bytes(self):
+    return ByteStream(open(self.os_path, "rb"))
 
 
 def _get_extension(file_name):
@@ -60,3 +65,24 @@ def _get_extension(file_name):
         extension = parts[-1]
         return name, extension
     return file_name, ""
+
+
+class File_usingStream:
+    """
+    A File USING A BORROW STREAM.  FOR USE IN TAR AND ZIP FILES
+    """
+
+    rel_path: str
+
+    def __init__(self, rel_path, content):
+        self.rel_path = rel_path
+        self._content = content
+
+    def content(self):
+        return self._content()
+
+    def bytes(self):
+        return self._content()
+
+
+export("mo_streams.byte_stream", File_usingStream)
\ No newline at end of file
